<template>
    <div class="personnel">
        <!-- 面包屑 -->
        <div class="breadcrumb">
            <div v-for="(item, index) in breadList">
                <span
                    :style="{
                        color: breadList.length - 1 > index ? '#367ac8' : '',
                    }"
                    @click="handleBread(item, index)"
                    >{{ item.name }}</span
                >
                <van-icon
                    style="margin: 0 0.3rem"
                    name="arrow"
                    v-if="index !== breadList.length - 1"
                />
            </div>
        </div>
        <!-- 树 -->
        <div v-for="(org, orgin) in currentList">
            <!-- 单选 -->
            <van-radio-group v-model="radio" v-if="isRadio">
                <van-cell
                    v-if="isPersonnel"
                    :title="org.fullname"
                    clickable
                    @click="handleFull(org)"
                >
                    <template #icon>
                        <van-icon name="manager" style="margin-right: 0.5rem" />
                    </template>
                    <template #right-icon>
                        <van-radio :name="org.id" />
                    </template>
                </van-cell>
                <van-cell
                    v-else
                    :title="org.name"
                    clickable
                    @click="handleOrg(org)"
                >
                    <template #icon>
                        <van-icon name="cluster" style="margin-right: 0.5rem" />
                    </template>
                    <template #right-icon>
                        <van-icon name="arrow" />
                    </template>
                </van-cell>
            </van-radio-group>
            <!-- 多选 -->
            <van-checkbox-group v-model="radio" v-if="!isRadio">
                <van-cell
                    v-if="isPersonnel"
                    :title="org.fullname"
                    clickable
                    @click="handleFull(org, orgin)"
                >
                    <template #icon>
                        <van-icon name="manager" style="margin-right: 0.5rem" />
                    </template>
                    <template #right-icon>
                        <van-checkbox :name="org.id" ref="checkboxes" />
                    </template>
                </van-cell>
                <van-cell
                    v-else
                    :title="org.name"
                    clickable
                    @click="handleOrg(org)"
                >
                    <template #icon>
                        <van-icon name="cluster" style="margin-right: 0.5rem" />
                    </template>
                    <template #right-icon>
                        <van-icon name="arrow" />
                    </template>
                </van-cell>
            </van-checkbox-group>
        </div>
    </div>
</template>
<script>
import api from '@/api/device/AskForLeave.js'

export default {
    name: 'personnelDialog',
    components: {},
    props: {
        isRadio: {
            type: Boolean,
            default: true,
        },
    },
    data() {
        return {
            activeNames: [1],
            activeNames1: [],
            value: '',
            list: [],
            loading: false,
            finished: false,
            queryParam: {
                pageBean: {
                    page: 1,
                    pageSize: -1,
                },
                querys: [],
            },
            querys: [
                {
                    group: 'main',
                    operation: 'LIKE',
                    parentGroup: '',
                    property: 'fullname',
                    relation: 'AND',
                    value: '',
                },
            ],
            tissueList: [], //组织
            personnelList: [], //人员
            currentList: [], //当前
            total: 0,
            radio: null,
            breadList: [
                {
                    name: '组织人员',
                },
            ], //面包屑
            isPersonnel: false,
        }
    },
    created() {},
    methods: {
        //打开
        open(ids) {
            this.radio = []
            if (this.isRadio) {
                this.radio = ''
            } else {
                this.radio = ids
            }
            this.isPersonnel = false
            this.currentList = []
            this.tissueList = []
            this.personnelList = []
            this.breadList = [
                {
                    name: '组织人员',
                },
            ]
            this.getTissueData()
        },
        //获取人员
        getPersonnel(item) {
            this.currentList = []
            this.breadList.push(item)
            this.queryParam.querys = [
                {
                    group: 'orgTree',
                    operation: 'IN',
                    property: 'ORG_ID_',
                    relation: 'AND',
                    value: item.id,
                },
            ]
            api.personnelData(this.queryParam, (res) => {
                if (res.rows) {
                    this.currentList = res.rows
                }
            })
        },
        //获取部门
        getTissueData() {
            api.tissueData({}, (res) => {
                if (res) {
                    this.tissueList = res
                    this.currentList = res
                }
            })
        },
        handleOrg(item) {
            if (item.children.length > 0) {
                this.isPersonnel = false
                this.breadList.push(item)
                this.currentList = item.children
            } else {
                this.isPersonnel = true
                this.getPersonnel(item)
            }
        },
        //勾选人员
        handleFull(item, index) {
            if (this.isRadio) {
                this.radio = item.id
            } else {
                this.$refs.checkboxes[index].toggle()
            }
            //将勾选人员信息传给父组件
            this.$emit('handleFull', item)
        },
        handleBread(item, index) {
            this.isPersonnel = false
            this.breadList.splice(index + 1)
            console.log(item);
            if (item.id) {
                // let ary = this.findNodeById(item.id)
                this.currentList = item.children
            } else {
                console.log(1111);
                this.currentList = this.tissueList
            }
        },
        findNodeById(id) {
            for (let i = 0; i < this.tissueList.length; i++) {
                const node = this.tissueList[i]
                if (node.id === id) {
                    return node
                }
                if (node.children) {
                    const foundNode = this.findNodeById(node.children, id)
                    if (foundNode) {
                        return foundNode
                    }
                }
            }
            return null
        },
    },
}
</script>
<style lang="scss" scoped>
.personnel {
    min-height: 8rem;
    padding: 0 1rem;
    box-sizing: border-box;
    color: #999;

    .breadcrumb {
        width: 100%;
        overflow-x: auto;
        display: flex;
        white-space: nowrap
    }
}

::v-deep .van-cell {
    display: flex;
    align-items: center;
    line-height: 3rem;
}
</style>